Original authors of class NocaseDict when it was part of pywbem:

```
Bart Whiteley <bwhiteley@gmail.com>
Karl Schopmeyer <k.schopmeyer@swbell.net>
Karl Schopmeyer <kschopmeyer@inovaserver3.inovadevelopment.com>
Tim Potter <tpot@hp.com>
```
